@@ -1,7 +1,7 @@
 /*
  *  birthdaydlg.cpp  -  dialog to pick birthdays from address book
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -67,7 +67,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 
     // Prefix and suffix to the name in the alarm text
     // Get default prefix and suffix texts from config file
-    KConfigGroup config(KSharedConfig::openConfig(), "General");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
     mPrefixText = config.readEntry("BirthdayPrefix", i18nc("@info", "Birthday: "));
     mSuffixText = config.readEntry("BirthdaySuffix");
 
@@ -239,10 +239,10 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 /******************************************************************************
 * Return a list of events for birthdays chosen.
 */
-QVector<KAEvent> BirthdayDlg::events() const
+QList<KAEvent> BirthdayDlg::events() const
 {
-    QVector<KAEvent> list;
-    const QModelIndexList indexes = mListView->selectionModel()->selectedRows();     //clazy:exclude=inefficient-qlist
+    QList<KAEvent> list;
+    const QModelIndexList indexes = mListView->selectionModel()->selectedRows();
     const int count = indexes.count();
     if (!count)
         return list;
@@ -264,14 +264,14 @@ QVector<KAEvent> BirthdayDlg::events() const
                       (mName ? mName->text() : QString()),
                       mPrefix->text() + name + mSuffix->text(),
                       mFontColourButton->bgColour(), mFontColourButton->fgColour(),
-                      mFontColourButton->font(), KAEvent::MESSAGE, mLateCancel->minutes(),
+                      mFontColourButton->font(), KAEvent::SubAction::Message, mLateCancel->minutes(),
                       mFlags, true);
         float fadeVolume;
         int   fadeSecs;
         const float volume = mSoundPicker->volume(fadeVolume, fadeSecs);
         const int   repeatPause = mSoundPicker->repeatPause();
         event.setAudioFile(mSoundPicker->file().toDisplayString(), volume, fadeVolume, fadeSecs, repeatPause);
-        const QVector<int> months(1, date.month());
+        const QList<int> months(1, date.month());
         event.setRecurAnnualByDate(1, months, 0, KARecurrence::defaultFeb29Type(), -1, QDate());
         event.setRepetition(mSubRepetition->repetition());
         event.setNextOccurrence(todayStart);
@@ -293,7 +293,7 @@ QVector<KAEvent> BirthdayDlg::events() const
 void BirthdayDlg::slotOk()
 {
     // Save prefix and suffix texts to use as future defaults
-    KConfigGroup config(KSharedConfig::openConfig(), "General");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
     config.writeEntry("BirthdayPrefix", mPrefix->text());
     config.writeEntry("BirthdaySuffix", mSuffix->text());
     config.sync();
@@ -365,10 +365,10 @@ void BirthdayDlg::setSortModelSelectionList()
         return;
 
     QStringList alarmMessageList;
-    const QVector<KAEvent> activeEvents = ResourcesCalendar::events(CalEvent::ACTIVE);
+    const QList<KAEvent> activeEvents = ResourcesCalendar::events(CalEvent::ACTIVE);
     for (const KAEvent& event : activeEvents)
     {
-        if (event.actionSubType() == KAEvent::MESSAGE
+        if (event.actionSubType() == KAEvent::SubAction::Message
         &&  event.recurType() == KARecurrence::ANNUAL_DATE
         &&  (mPrefixText.isEmpty()  ||  event.message().startsWith(mPrefixText)))
             alarmMessageList.append(event.message());
@@ -376,4 +376,6 @@ void BirthdayDlg::setSortModelSelectionList()
     akonadiPlugin->setPrefixSuffix(mBirthdaySortModel, mPrefixText, mSuffixText, alarmMessageList);
 }
 
+#include "moc_birthdaydlg.cpp"
+
 // vim: et sw=4:
