@@ -100,11 +100,11 @@ EditAlarmDlg* EditAlarmDlg::create(bool Template, const KAEvent& event, bool new
 {
     switch (event.actionTypes())
     {
-        case KAEvent::ACT_COMMAND:  return new EditCommandAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
-        case KAEvent::ACT_DISPLAY_COMMAND:
-        case KAEvent::ACT_DISPLAY:  return new EditDisplayAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
-        case KAEvent::ACT_EMAIL:    return new EditEmailAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
-        case KAEvent::ACT_AUDIO:    return new EditAudioAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
+        case KAEvent::Action::Command:  return new EditCommandAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
+        case KAEvent::Action::DisplayCommand:
+        case KAEvent::Action::Display:  return new EditDisplayAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
+        case KAEvent::Action::Email:    return new EditEmailAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
+        case KAEvent::Action::Audio:    return new EditAudioAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
         default:
             break;
     }
@@ -156,7 +156,7 @@ void EditAlarmDlg::init(const KAEvent& event, GetResourceType getResource)
                 mUseResourceEventId = true;
                 break;
             }
-            Q_FALLTHROUGH();   // fall through to RES_PROMPT
+            [[fallthrough]];   // fall through to RES_PROMPT
         case RES_PROMPT:
             mResourceEventId.clear();
             mUseResourceEventId = true;
@@ -366,13 +366,25 @@ void EditAlarmDlg::init(const KAEvent& event)
     // Late cancel selector - default = allow late display
     mLateCancel = new LateCancelSelector(true, mMoreOptions);
     connect(mLateCancel, &LateCancelSelector::changed, this, &EditAlarmDlg::contentsChanged);
-    moreLayout->addWidget(mLateCancel, 0, Qt::AlignLeft);
+    auto layout = new QHBoxLayout;
+    layout->setContentsMargins(0, 0, 0, 0);
+    layout->addWidget(mLateCancel, 1);
+    moreLayout->addLayout(layout);
 
     PackedLayout* playout = new PackedLayout(Qt::AlignJustify);
     playout->setHorizontalSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     playout->setVerticalSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     moreLayout->addLayout(playout);
 
+    if (KernelWakeAlarm::isAvailable())
+    {
+        // Wake from suspend checkbox
+        mWakeFromSuspend = new CheckBox(i18nc("@option:check", "Wake from suspend"), mMoreOptions);
+        connect(mWakeFromSuspend, &CheckBox::toggled, this, &EditAlarmDlg::contentsChanged);
+        mWakeFromSuspend->setWhatsThis(i18nc("@info:whatsthis", "Check to wake the system if the alarm triggers while the system is suspended"));
+        playout->addWidget(mWakeFromSuspend);
+    }
+
     // Acknowledgement confirmation required - default = no confirmation
     CheckBox* confirmAck = type_createConfirmAckCheckbox(mMoreOptions);
     if (confirmAck)
@@ -387,13 +399,16 @@ void EditAlarmDlg::init(const KAEvent& event)
         mShowInKorganizer = new CheckBox(i18n_chk_ShowInKOrganizer(), mMoreOptions);
         connect(mShowInKorganizer, &CheckBox::toggled, this, &EditAlarmDlg::contentsChanged);
         mShowInKorganizer->setWhatsThis(i18nc("@info:whatsthis", "Check to copy the alarm into KOrganizer's calendar"));
-        playout->addWidget(mShowInKorganizer);
+        if (!confirmAck  ||  !mWakeFromSuspend)
+            playout->addWidget(mShowInKorganizer);
+        else
+            mLateCancel->addWidget(mShowInKorganizer);
     }
 
     mainLayout->addWidget(mButtonBox);
 
     // Hide optional controls
-    KConfigGroup config(KSharedConfig::openConfig(), EDIT_MORE_GROUP);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(EDIT_MORE_GROUP));
     showOptions(config.readEntry(EDIT_MORE_KEY, false));
 
     // Initialise the state of all controls according to the specified event, if any
@@ -522,6 +537,8 @@ void EditAlarmDlg::initValues(const KAEvent& event)
 
         mLateCancel->setMinutes(event.lateCancel(), event.startDateTime().isDateOnly(),
                                 TimePeriod::HoursMinutes);
+        if (mWakeFromSuspend)
+            mWakeFromSuspend->setChecked(event.wakeFromSuspend());
         if (mShowInKorganizer)
             mShowInKorganizer->setChecked(event.copyToKOrganizer());
         type_initValues(event);
@@ -541,6 +558,8 @@ void EditAlarmDlg::initValues(const KAEvent& event)
         else
             mTimeWidget->setDateTime(defaultTime);
         mLateCancel->setMinutes((Preferences::defaultLateCancel() ? 1 : 0), false, TimePeriod::HoursMinutes);
+        if (mWakeFromSuspend)
+            mWakeFromSuspend->setChecked(false);
         if (mShowInKorganizer)
             mShowInKorganizer->setChecked(Preferences::defaultCopyToKOrganizer());
         type_initValues(KAEvent());
@@ -592,9 +611,15 @@ void EditAlarmDlg::setLateCancel(int minutes)
     mLateCancel->setMinutes(minutes, mTimeWidget->getDateTime(false, false).isDateOnly(),
                             TimePeriod::HoursMinutes);
 }
+void EditAlarmDlg::setWakeFromSuspend(bool wake)
+{
+    if (mWakeFromSuspend)
+        mWakeFromSuspend->setChecked(wake);
+}
 void EditAlarmDlg::setShowInKOrganizer(bool show)
 {
-    mShowInKorganizer->setChecked(show);
+    if (mShowInKorganizer)
+        mShowInKorganizer->setChecked(show);
 }
 
 /******************************************************************************
@@ -614,6 +639,8 @@ void EditAlarmDlg::setReadOnly(bool readOnly)
         else
             mDeferChangeButton->show();
     }
+    if (mWakeFromSuspend)
+        mWakeFromSuspend->setReadOnly(readOnly);
     if (mShowInKorganizer)
         mShowInKorganizer->setReadOnly(readOnly);
 }
@@ -639,6 +666,8 @@ void EditAlarmDlg::saveState(const KAEvent* event)
     if (mTimeWidget)
         mSavedDateTime = mTimeWidget->getDateTime(false, false);
     mSavedLateCancel       = mLateCancel->minutes();
+    if (mWakeFromSuspend)
+        mSavedWakeFromSuspend = mWakeFromSuspend->isChecked();
     if (mShowInKorganizer)
         mSavedShowInKorganizer = mShowInKorganizer->isChecked();
     mSavedRecurrenceType   = mRecurrenceEdit->repeatType();
@@ -676,6 +705,7 @@ bool EditAlarmDlg::stateChanged() const
             return true;
     }
     if (mSavedLateCancel       != mLateCancel->minutes()
+    ||  (mWakeFromSuspend && mSavedWakeFromSuspend != mWakeFromSuspend->isChecked())
     ||  (mShowInKorganizer && mSavedShowInKorganizer != mShowInKorganizer->isChecked())
     ||  textFileCommandMessage != mSavedTextFileCommandMessage
     ||  mSavedRecurrenceType   != mRecurrenceEdit->repeatType())
@@ -748,7 +778,7 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
             dt = KADateTime(QDate(2000,1,1), mTemplateTime->time());
     }
 
-    int lateCancel = (trial || !mLateCancel->isEnabled()) ? 0 : mLateCancel->minutes();
+    const int lateCancel = (trial || !mLateCancel->isEnabled()) ? 0 : mLateCancel->minutes();
     type_setEvent(event, dt, (mName ? mName->text() : QString()), text, lateCancel, trial);
 
     if (!trial)
@@ -801,6 +831,8 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
 KAEvent::Flags EditAlarmDlg::getAlarmFlags() const
 {
     KAEvent::Flags flags{};
+    if (mWakeFromSuspend && mWakeFromSuspend->isEnabled() && mWakeFromSuspend->isChecked())
+        flags |= KAEvent::WAKE_SUSPEND;
     if (mShowInKorganizer && mShowInKorganizer->isEnabled() && mShowInKorganizer->isChecked())
         flags |= KAEvent::COPY_KORGANIZER;
     if (mRecurrenceEdit->repeatType() == RecurrenceEdit::AT_LOGIN)
@@ -1021,7 +1053,7 @@ bool EditAlarmDlg::validate()
             else
                 pre = pre.addSecs(-1);
             DateTime next;
-            event.nextOccurrence(pre, next, KAEvent::IGNORE_REPETITION);
+            event.nextOccurrence(pre, next, KAEvent::Repeats::Ignore);
             if (next != dt)
             {
                 QString prompt = dateOnly ? i18nc("@info The parameter is a date value",
@@ -1049,12 +1081,12 @@ bool EditAlarmDlg::validate()
             {
                 // A timed recurrence has an entered start date which
                 // has already expired, so we must adjust it.
-                if (event.nextOccurrence(now, mAlarmDateTime, KAEvent::ALLOW_FOR_REPETITION) == KAEvent::NO_OCCURRENCE)
+                if (event.nextOccurrence(now, mAlarmDateTime, KAEvent::Repeats::RecurBefore) == KAEvent::OccurType::None)
                 {
                     KAMessageBox::error(this, i18nc("@info", "Recurrence has already expired"));
                     return false;
                 }
-                if (event.workTimeOnly()  &&  !event.nextTrigger(KAEvent::DISPLAY_TRIGGER).isValid())
+                if (event.workTimeOnly()  &&  !event.nextTrigger(KAEvent::Trigger::Display).isValid())
                 {
                     if (KAMessageBox::warningContinueCancel(this, i18nc("@info", "The alarm will never occur during working hours"))
                         != KMessageBox::Continue)
@@ -1176,14 +1208,14 @@ void EditAlarmDlg::slotTry()
 */
 void EditAlarmDlg::slotHelp()
 {
-    KAEvent::Actions type;
+    KAEvent::Action type;
     switch (mAlarmType)
     {
-        case KAEvent::FILE:
-        case KAEvent::MESSAGE:  type = KAEvent::ACT_DISPLAY;  break;
-        case KAEvent::COMMAND:  type = KAEvent::ACT_COMMAND;  break;
-        case KAEvent::EMAIL:    type = KAEvent::ACT_EMAIL;  break;
-        case KAEvent::AUDIO:    type = KAEvent::ACT_AUDIO;  break;
+        case KAEvent::SubAction::File:
+        case KAEvent::SubAction::Message:  type = KAEvent::Action::Display;  break;
+        case KAEvent::SubAction::Command:  type = KAEvent::Action::Command;  break;
+        case KAEvent::SubAction::Email:    type = KAEvent::Action::Email;  break;
+        case KAEvent::SubAction::Audio:    type = KAEvent::Action::Audio;  break;
         default:
             return;
     }
@@ -1206,7 +1238,7 @@ void EditAlarmDlg::slotHelp()
 void EditAlarmDlg::slotDefault()
 {
     showOptions(!mShowingMore);
-    KConfigGroup config(KSharedConfig::openConfig(), EDIT_MORE_GROUP);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(EDIT_MORE_GROUP));
     config.writeEntry(EDIT_MORE_KEY, mShowingMore);
 }
 
@@ -1378,6 +1410,7 @@ void EditAlarmDlg::slotRecurTypeChange(int repeatType)
     if (mReminder)
         mReminder->setAfterOnly(atLogin);
     mLateCancel->setEnabled(!atLogin);
+    setWakeFromSuspendEnabledStatus();
     if (mShowInKorganizer)
         mShowInKorganizer->setEnabled(!atLogin);
     slotRecurFrequencyChange();
@@ -1418,6 +1451,7 @@ void EditAlarmDlg::slotTemplateTimeType(QAbstractButton*)
 {
     mTemplateTime->setEnabled(mTemplateUseTime->isChecked());
     mTemplateTimeAfter->setEnabled(mTemplateUseTimeAfter->isChecked());
+    slotAnyTimeToggled(mTemplateAnyTime && mTemplateAnyTime->isChecked());
 }
 
 /******************************************************************************
@@ -1426,9 +1460,24 @@ void EditAlarmDlg::slotTemplateTimeType(QAbstractButton*)
 */
 void EditAlarmDlg::slotAnyTimeToggled(bool anyTime)
 {
-    if (mReminder  &&  mReminder->isReminder())
+    if (mReminder)
         mReminder->setDateOnly(anyTime);
     mLateCancel->setDateOnly(anyTime);
+    setWakeFromSuspendEnabledStatus();
+}
+
+/******************************************************************************
+* Enable or disable the wake-from-suspend checkbox as appropriate.
+*/
+void EditAlarmDlg::setWakeFromSuspendEnabledStatus()
+{
+    if (mWakeFromSuspend)
+    {
+        bool atLogin = (mRecurrenceEdit->repeatType() == RecurrenceEdit::AT_LOGIN);
+        bool anyTime = (mTimeWidget && mTimeWidget->anyTimeSelected())
+                   ||  (mTemplateAnyTime && mTemplateAnyTime->isChecked());
+        mWakeFromSuspend->setEnabled(!atLogin && !anyTime);
+    }
 }
 
 bool EditAlarmDlg::dateOnly() const
