@@ -1,7 +1,7 @@
 /*
  *  eventlistview.cpp  -  base class for widget showing list of alarms
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2007-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -82,7 +82,7 @@ void EventListView::select(const QModelIndex& index, bool scrollToIndex)
 */
 QModelIndex EventListView::selectedIndex() const
 {
-    const QModelIndexList list = selectionModel()->selectedRows();      //clazy:exclude=inefficient-qlist
+    const QModelIndexList list = selectionModel()->selectedRows();
     if (list.count() != 1)
         return {};
     return list[0];
@@ -94,7 +94,7 @@ QModelIndex EventListView::selectedIndex() const
 */
 KAEvent EventListView::selectedEvent() const
 {
-    const QModelIndexList list = selectionModel()->selectedRows();      //clazy:exclude=inefficient-qlist
+    const QModelIndexList list = selectionModel()->selectedRows();
     if (list.count() != 1)
         return {};
     const auto model = static_cast<const EventListModel*>(list[0].model());
@@ -104,10 +104,10 @@ KAEvent EventListView::selectedEvent() const
 /******************************************************************************
 * Return the selected events.
 */
-QVector<KAEvent> EventListView::selectedEvents() const
+QList<KAEvent> EventListView::selectedEvents() const
 {
-    QVector<KAEvent> elist;
-    const QModelIndexList ixlist = selectionModel()->selectedRows();      //clazy:exclude=inefficient-qlist
+    QList<KAEvent> elist;
+    const QModelIndexList ixlist = selectionModel()->selectedRows();
     int count = ixlist.count();
     if (count)
     {
@@ -175,7 +175,7 @@ bool EventListView::viewportEvent(QEvent* e)
                 auto m = qobject_cast<EventListModel*>(model());
                 if (index.column() == ResourceDataModelBase::TextColumn
                 ||  index.column() == ResourceDataModelBase::NameColumn
-                ||  !m  ||  m->event(index).commandError() == KAEvent::CMD_NO_ERROR)
+                ||  !m  ||  m->event(index).commandError() == KAEvent::CmdErr::None)
                 {
                     // Single line tooltip. Only display it if the text column
                     // is truncated in the view display.
@@ -206,13 +206,9 @@ void EventListView::contextMenuEvent(QContextMenuEvent* e)
 
 QStyleOptionViewItem EventListView::listViewOptions() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    return QTreeView::viewOptions();
-#else
     QStyleOptionViewItem option;
     initViewItemOption(&option);
     return option;
-#endif
 }
 
 
@@ -259,4 +255,6 @@ bool EventListDelegate::editorEvent(QEvent* e, QAbstractItemModel* model, const
     return false;   // indicate that the event has not been handled
 }
 
+#include "moc_eventlistview.cpp"
+
 // vim: et sw=4:
