@@ -1,7 +1,7 @@
 /*
  *  functions.cpp  -  miscellaneous functions
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -28,22 +28,21 @@
 #include "akonadiplugin/akonadiplugin.h"
 #include "kalarm_debug.h"
 
-#include <kcalendarcore_version.h>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/Person>
 #include <KCalendarCore/Duration>
 #include <KCalendarCore/MemoryCalendar>
 using namespace KCalendarCore;
-#include <KIdentityManagement/IdentityManager>
-#include <KIdentityManagement/Identity>
+#include <KIdentityManagementCore/IdentityManager>
+#include <KIdentityManagementCore/Identity>
 
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KToggleAction>
 #include <KLocalizedString>
 
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
 #include <KAuth/ActionReply>
 #include <KAuth/ExecuteJob>
 #endif
@@ -53,8 +52,9 @@ using namespace KCalendarCore;
 #include <KIO/StatJob>
 #include <KIO/StoredTransferJob>
 #include <KFileCustomDialog>
-#include <KWindowInfo>
+#include <KWindowSystem>
 #if ENABLE_X11
+#include <KWindowInfo>
 #include <KX11Extras>
 #endif
 
@@ -62,7 +62,6 @@ using namespace KCalendarCore;
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
 #include <QTimer>
-#include <QtGlobal>
 #include <QMimeData>
 #include <QStandardPaths>
 #include <QPushButton>
@@ -177,7 +176,7 @@ MainWindow* displayMainWindowSelected(const QString& eventId)
         win->setWindowState(win->windowState() & ~Qt::WindowMinimized);
         win->show();
         win->raise();
-        win->activateWindow();
+        KWindowSystem::activateWindow(win->windowHandle());
     }
     if (win)
         win->selectEvent(eventId);
@@ -189,7 +188,7 @@ MainWindow* displayMainWindowSelected(const QString& eventId)
 */
 KToggleAction* createAlarmEnableAction(QObject* parent)
 {
-    KToggleAction* action = new KToggleAction(i18nc("@action", "Enable &Alarms"), parent);
+    KToggleAction* action = new KToggleAction(i18nc("@action", "Enable Alarms"), parent);
     action->setChecked(theApp()->alarmsEnabled());
     QObject::connect(action, &QAction::toggled, theApp(), &KAlarmApp::setAlarmsEnabled);
     // The following line ensures that all instances are kept in the same state
@@ -275,7 +274,8 @@ UpdateResult addEvent(KAEvent& event, Resource& resource, QWidget* msgParent, in
 * Add a list of new active (non-archived) alarms, and save them in the resource.
 * The events are updated with their actual event IDs.
 */
-UpdateResult addEvents(QVector<KAEvent>& events, Resource& resource, QWidget* msgParent, bool allowKOrgUpdate, bool showKOrgErr)
+UpdateResult addEvents(QList<KAEvent>& events, Resource& resource, QWidget* msgParent,
+                       bool allowKOrgUpdate, bool showKOrgErr)
 {
     qCDebug(KALARM_LOG) << "KAlarm::addEvents:" << events.count();
     if (events.isEmpty())
@@ -473,17 +473,17 @@ UpdateResult updateTemplate(KAEvent& event, QWidget* msgParent)
 */
 UpdateResult deleteEvent(KAEvent& event, Resource& resource, bool archive, QWidget* msgParent, bool showKOrgErr)
 {
-    QVector<KAEvent> events(1, event);
+    QList<KAEvent> events(1, event);
     return deleteEvents(events, resource, archive, msgParent, showKOrgErr);
 }
 
-UpdateResult deleteEvents(QVector<KAEvent>& events, Resource& resource, bool archive, QWidget* msgParent, bool showKOrgErr)
+UpdateResult deleteEvents(QList<KAEvent>& events, Resource& resource, bool archive, QWidget* msgParent, bool showKOrgErr)
 {
     qCDebug(KALARM_LOG) << "KAlarm::deleteEvents:" << events.count();
     if (events.isEmpty())
         return UpdateResult(UPDATE_OK);
     UpdateStatusData status;
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
     bool deleteWakeFromSuspendAlarm = false;
     const QString wakeFromSuspendId = checkRtcWakeConfig().value(0);
 #endif
@@ -518,7 +518,7 @@ UpdateResult deleteEvents(QVector<KAEvent>& events, Resource& resource, bool arc
         else
             status.appendFailed(i);
 
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
         if (id == wakeFromSuspendId)
             deleteWakeFromSuspendAlarm = true;
 #endif
@@ -545,7 +545,7 @@ UpdateResult deleteEvents(QVector<KAEvent>& events, Resource& resource, bool arc
     if (status.status != UPDATE_OK  &&  msgParent)
         displayUpdateError(msgParent, ERR_DELETE, status, showKOrgErr);
 
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
     // Remove any wake-from-suspend scheduled for a deleted alarm
     if (deleteWakeFromSuspendAlarm  &&  !wakeFromSuspendId.isEmpty())
         cancelRtcWake(msgParent, wakeFromSuspendId);
@@ -616,12 +616,13 @@ void deleteDisplayEvent(const QString& eventID)
 */
 UpdateResult reactivateEvent(KAEvent& event, Resource& resource, QWidget* msgParent, bool showKOrgErr)
 {
-    QVector<int> ids;
-    QVector<KAEvent> events(1, event);
+    QList<int> ids;
+    QList<KAEvent> events(1, event);
     return reactivateEvents(events, ids, resource, msgParent, showKOrgErr);
 }
 
-UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<int>& ineligibleIndexes, Resource& resource, QWidget* msgParent, bool showKOrgErr)
+UpdateResult reactivateEvents(QList<KAEvent>& events, QList<int>& ineligibleIndexes,
+                              Resource& resource, QWidget* msgParent, bool showKOrgErr)
 {
     qCDebug(KALARM_LOG) << "KAlarm::reactivateEvents:" << events.count();
     ineligibleIndexes.clear();
@@ -639,7 +640,7 @@ UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<int>& ineligible
     {
         int count = 0;
         const KADateTime now = KADateTime::currentUtcDateTime();
-        QVector<KAEvent> eventsToDelete;
+        QList<KAEvent> eventsToDelete;
         for (int i = 0, end = events.count();  i < end;  ++i)
         {
             // Delete the event from the archived resource
@@ -709,13 +710,13 @@ UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<int>& ineligible
 * Enable or disable alarms.
 * The new events will have the same event IDs as the old ones.
 */
-UpdateResult enableEvents(QVector<KAEvent>& events, bool enable, QWidget* msgParent)
+UpdateResult enableEvents(QList<KAEvent>& events, bool enable, QWidget* msgParent)
 {
     qCDebug(KALARM_LOG) << "KAlarm::enableEvents:" << events.count();
     if (events.isEmpty())
         return UpdateResult(UPDATE_OK);
     UpdateStatusData status;
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
     bool deleteWakeFromSuspendAlarm = false;
     const QString wakeFromSuspendId = checkRtcWakeConfig().value(0);
 #endif
@@ -728,7 +729,7 @@ UpdateResult enableEvents(QVector<KAEvent>& events, bool enable, QWidget* msgPar
         {
             event->setEnabled(enable);
 
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
             if (!enable  &&  event->id() == wakeFromSuspendId)
                 deleteWakeFromSuspendAlarm = true;
 #endif
@@ -746,7 +747,7 @@ UpdateResult enableEvents(QVector<KAEvent>& events, bool enable, QWidget* msgPar
                 ResourcesCalendar::disabledChanged(newev);
 
                 // If we're disabling a display alarm, close any message display
-                if (!enable  &&  (event->actionTypes() & KAEvent::ACT_DISPLAY))
+                if (!enable  &&  (event->actionTypes() & KAEvent::Action::Display))
                 {
                     MessageDisplay* win = MessageDisplay::findEvent(EventId(*event));
                     delete win;
@@ -775,7 +776,7 @@ UpdateResult enableEvents(QVector<KAEvent>& events, bool enable, QWidget* msgPar
     if (status.status != UPDATE_OK  &&  msgParent)
         displayUpdateError(msgParent, ERR_ADD, status);
 
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
     // Remove any wake-from-suspend scheduled for a disabled alarm
     if (deleteWakeFromSuspendAlarm  &&  !wakeFromSuspendId.isEmpty())
         cancelRtcWake(msgParent, wakeFromSuspendId);
@@ -801,7 +802,7 @@ void purgeArchive(int purgeDays)
     const Resource resource = Resources::getStandard(CalEvent::ARCHIVED, true);
     if (!resource.isValid())
         return;
-    QVector<KAEvent> events = ResourcesCalendar::events(resource);
+    QList<KAEvent> events = ResourcesCalendar::events(resource);
     for (int i = 0;  i < events.count();  )
     {
         if (purgeDays  &&  events.at(i).createdDateTime().date() >= cutoff)
@@ -829,7 +830,7 @@ bool eventReadOnly(const QString& eventId)
 * If 'model' is non-null, the AlarmListModel* which it points to is used; if
 * that is null, it is created.
 */
-QVector<KAEvent> getSortedActiveEvents(QObject* parent, AlarmListModel** model)
+QList<KAEvent> getSortedActiveEvents(QObject* parent, AlarmListModel** model)
 {
     AlarmListModel* mdl = nullptr;
     if (!model)
@@ -841,7 +842,7 @@ QVector<KAEvent> getSortedActiveEvents(QObject* parent, AlarmListModel** model)
         (*model)->sort(AlarmListModel::TimeColumn);
     }
     int count = (*model)->rowCount();
-    QVector<KAEvent> result;
+    QList<KAEvent> result;
     result.reserve(count);
     for (int i = 0;  i < count;  ++i)
     {
@@ -873,7 +874,7 @@ bool importAlarms(Resource& resource, QWidget* parent)
     KFileWidget* widget = dlg->fileWidget();
     widget->setOperationMode(KFileWidget::Opening);
     widget->setMode(KFile::Files | KFile::ExistingOnly);
-    widget->setMimeFilter({QStringLiteral("text/calendar")});
+    widget->setFilters({KFileFilter::fromMimeType(QStringLiteral("text/calendar"))});
     dlg->setWindowModality(Qt::WindowModal);
     dlg->exec();
     if (!dlg)
@@ -886,7 +887,7 @@ bool importAlarms(Resource& resource, QWidget* parent)
     const CalEvent::Types alarmTypes = resource.isValid() ? resource.alarmTypes() : CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE;
 
     // Read all the selected calendar files and extract their alarms.
-    QHash<CalEvent::Type, QVector<KAEvent>> events;
+    QHash<CalEvent::Type, QList<KAEvent>> events;
     for (const QUrl& url : urls)
     {
         if (!url.isValid())
@@ -926,11 +927,11 @@ bool importAlarms(Resource& resource, QWidget* parent)
 * Reply = true if all alarms in the calendar were successfully exported
 *       = false if any alarms failed to be exported.
 */
-bool exportAlarms(const QVector<KAEvent>& events, QWidget* parent)
+bool exportAlarms(const QList<KAEvent>& events, QWidget* parent)
 {
     bool append;
     QString file = FileDialog::getSaveFileName(lastExportUrl,
-                                               QStringLiteral("*.ics|%1").arg(i18nc("@item:inlistbox File type selection filter", "Calendar Files")),
+                                               {KFileFilter(i18nc("@item:inlistbox File type selection filter", "Calendar Files"), {QStringLiteral("*.ics")}, {})},
                                                parent, i18nc("@title:window", "Choose Export Calendar"),
                                                &append);
     if (file.isEmpty())
@@ -948,7 +949,7 @@ bool exportAlarms(const QVector<KAEvent>& events, QWidget* parent)
     FileStorage::Ptr calStorage(new FileStorage(calendar, file));
     if (append  &&  !calStorage->load())
     {
-        auto statJob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatDetail::StatDefaultDetails);
+        auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatDetail::StatDefaultDetails);
         KJobWidgets::setWindow(statJob, parent);
         statJob->exec();
         KFileItem fi(statJob->statResult(), url);
@@ -971,7 +972,7 @@ bool exportAlarms(const QVector<KAEvent>& events, QWidget* parent)
         const CalEvent::Type type = event.category();
         const QString id = CalEvent::uid(kcalEvent->uid(), type);
         kcalEvent->setUid(id);
-        event.updateKCalEvent(kcalEvent, KAEvent::UID_IGNORE);
+        event.updateKCalEvent(kcalEvent, KAEvent::UidAction::Ignore);
         if (calendar->addEvent(kcalEvent))
             exported = true;
         else
@@ -1014,9 +1015,6 @@ bool exportAlarms(const QVector<KAEvent>& events, QWidget* parent)
         }
         delete tempFile;
     }
-#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    calendar->close();
-#endif
     return success;
 }
 
@@ -1090,18 +1088,18 @@ void editNewAlarm(KAEvent::SubAction action, QWidget* parent, const AlarmText* t
     EditAlarmDlg::Type type;
     switch (action)
     {
-        case KAEvent::MESSAGE:
-        case KAEvent::FILE:
+        case KAEvent::SubAction::Message:
+        case KAEvent::SubAction::File:
             type = EditAlarmDlg::DISPLAY;
             setAction = true;
             break;
-        case KAEvent::COMMAND:
+        case KAEvent::SubAction::Command:
             type = EditAlarmDlg::COMMAND;
             break;
-        case KAEvent::EMAIL:
+        case KAEvent::SubAction::Email:
             type = EditAlarmDlg::EMAIL;
             break;
-        case KAEvent::AUDIO:
+        case KAEvent::SubAction::Audio:
             type = EditAlarmDlg::AUDIO;
             break;
         default:
@@ -1240,7 +1238,7 @@ void editNewTemplate(const KAEvent& preset, QWidget* parent)
     ::editNewTemplate(EditAlarmDlg::Type(0), preset, parent);
 }
 
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
 /******************************************************************************
 * Check the config as to whether there is a wake-on-suspend alarm pending, and
 * if so, delete it from the config if it has expired.
@@ -1253,7 +1251,7 @@ void editNewTemplate(const KAEvent& preset, QWidget* parent)
 */
 QStringList checkRtcWakeConfig(bool checkEventExists)
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "General");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
     const QStringList params = config.readEntry("RtcWake", QStringList());
     if (params.count() == 3  &&  params[2].toLongLong() > KADateTime::currentUtcDateTime().toSecsSinceEpoch())
     {
@@ -1278,7 +1276,7 @@ QStringList checkRtcWakeConfig(bool checkEventExists)
 */
 void deleteRtcWakeConfig()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "General");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
     config.deleteEntry("RtcWake");
     config.sync();
 }
@@ -1318,7 +1316,8 @@ bool setRtcWakeTime(unsigned triggerTime, QWidget* parent)
     args[QStringLiteral("time")] = triggerTime;
     KAuth::Action action(QStringLiteral("org.kde.kalarm.rtcwake.settimer"));
     action.setHelperId(QStringLiteral("org.kde.kalarm.rtcwake"));
-    action.setParentWidget(parent);
+    parent->window()->winId();
+    action.setParentWindow(parent->window()->windowHandle());
     action.setArguments(args);
     KAuth::ExecuteJob* job = action.execute();
     if (!job->exec())
@@ -1344,7 +1343,7 @@ bool setRtcWakeTime(unsigned triggerTime, QWidget* parent)
     }
     return true;
 }
-#endif // ENABLE_WAKE_FROM_SUSPEND
+#endif // ENABLE_RTC_WAKE_FROM_SUSPEND
 
 } // namespace KAlarm
 namespace
@@ -1586,14 +1585,14 @@ void updateEditedAlarm(EditAlarmDlg* editDlg, KAEvent& event, Resource& resource
 * Returns a list of all alarm templates.
 * If shell commands are disabled, command alarm templates are omitted.
 */
-QVector<KAEvent> templateList()
+QList<KAEvent> templateList()
 {
-    QVector<KAEvent> templates;
+    QList<KAEvent> templates;
     const bool includeCmdAlarms = ShellProcess::authorised();
-    const QVector<KAEvent> events = ResourcesCalendar::events(CalEvent::TEMPLATE);
+    const QList<KAEvent> events = ResourcesCalendar::events(CalEvent::TEMPLATE);
     for (const KAEvent& event : events)
     {
-        if (includeCmdAlarms  ||  !(event.actionTypes() & KAEvent::ACT_COMMAND))
+        if (includeCmdAlarms  ||  !(event.actionTypes() & KAEvent::Action::Command))
             templates.append(event);
     }
     return templates;
@@ -1606,7 +1605,7 @@ QVector<KAEvent> templateList()
 */
 void outputAlarmWarnings(QWidget* parent, const KAEvent* event)
 {
-    if (event  &&  event->actionTypes() == KAEvent::ACT_EMAIL
+    if (event  &&  event->actionTypes() == KAEvent::Action::Email
     &&  Preferences::emailAddress().isEmpty())
         KAMessageBox::information(parent, xi18nc("@info Please set the 'From' email address...",
                                                 "<para>%1</para><para>Please set it in the Configuration dialog.</para>", KAMail::i18n_NeedFromEmailAddress()));
@@ -1645,15 +1644,15 @@ void refreshAlarmsIfQueued()
     if (refreshAlarmsQueued)
     {
         qCDebug(KALARM_LOG) << "KAlarm::refreshAlarmsIfQueued";
-        QVector<Resource> resources = Resources::enabledResources();
+        QList<Resource> resources = Resources::enabledResources();
         for (Resource& resource : resources)
             resource.reload();
 
         // Close any message displays for alarms which are now disabled
-        const QVector<KAEvent> events = ResourcesCalendar::events(CalEvent::ACTIVE);
+        const QList<KAEvent> events = ResourcesCalendar::events(CalEvent::ACTIVE);
         for (const KAEvent& event : events)
         {
-            if (!event.enabled()  &&  (event.actionTypes() & KAEvent::ACT_DISPLAY))
+            if (!event.enabled()  &&  (event.actionTypes() & KAEvent::Action::Display))
             {
                 MessageDisplay* win = MessageDisplay::findEvent(EventId(event));
                 delete win;
@@ -1680,7 +1679,7 @@ QStringList dontShowErrors(const EventId& eventId)
     if (eventId.isEmpty())
         return {};
     KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
-    KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
+    KConfigGroup group(&config, QLatin1String(DONT_SHOW_ERRORS_GROUP));
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     return group.readEntry(id, QStringList());
 }
@@ -1706,7 +1705,7 @@ void setDontShowErrors(const EventId& eventId, const QStringList& tags)
     if (eventId.isEmpty())
         return;
     KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
-    KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
+    KConfigGroup group(&config, QLatin1String(DONT_SHOW_ERRORS_GROUP));
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     if (tags.isEmpty())
         group.deleteEntry(id);
@@ -1724,7 +1723,7 @@ void setDontShowErrors(const EventId& eventId, const QString& tag)
     if (eventId.isEmpty()  ||  tag.isEmpty())
         return;
     KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
-    KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
+    KConfigGroup group(&config, QLatin1String(DONT_SHOW_ERRORS_GROUP));
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     QStringList tags = group.readEntry(id, QStringList());
     if (tags.indexOf(tag) < 0)
@@ -2017,7 +2016,7 @@ void displayUpdateError(QWidget* parent, KAlarm::UpdateError code, const UpdateS
 KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
 {
     Event::Ptr kcalEvent(new KCalendarCore::Event);
-    event.updateKCalEvent(kcalEvent, KAEvent::UID_IGNORE);
+    event.updateKCalEvent(kcalEvent, KAEvent::UidAction::Ignore);
     // Change the event ID to avoid duplicating the same unique ID as the original event
     const QString uid = uidKOrganizer(event.id());
     kcalEvent->setUid(uid);
@@ -2025,13 +2024,13 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
     QString userEmail;
     switch (event.actionTypes())
     {
-        case KAEvent::ACT_DISPLAY:
-        case KAEvent::ACT_COMMAND:
-        case KAEvent::ACT_DISPLAY_COMMAND:
+        case KAEvent::Action::Display:
+        case KAEvent::Action::Command:
+        case KAEvent::Action::DisplayCommand:
             kcalEvent->setSummary(event.cleanText());
             userEmail = Preferences::emailAddress();
             break;
-        case KAEvent::ACT_EMAIL:
+        case KAEvent::Action::Email:
         {
             const QString from = event.emailFromId()
                                ? Identities::identityManager()->identityForUoid(event.emailFromId()).fullEmailAddr()
@@ -2042,7 +2041,7 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
             userEmail = from;
             break;
         }
-        case KAEvent::ACT_AUDIO:
+        case KAEvent::Action::Audio:
             kcalEvent->setSummary(event.audioFile());
             break;
         default:
@@ -2062,7 +2061,7 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
     if (status != KAlarm::UPDATE_OK)
         return status;
     QDBusInterface korgInterface(KORG_DBUS_SERVICE, QStringLiteral(KORG_DBUS_PATH), KORG_DBUS_IFACE);
-    const QList<QVariant> args{iCal};             //clazy:exclude=inefficient-qlist
+    const QList<QVariant> args{iCal};
     QDBusReply<bool> reply = korgInterface.callWithArgumentList(QDBus::Block, QStringLiteral("addIncidence"), args);
     if (!reply.isValid())
     {
@@ -2146,4 +2145,6 @@ bool caseInsensitiveLessThan(const QString& s1, const QString& s2)
     return s1.toLower() < s2.toLower();
 }
 
+#include "moc_functions_p.cpp"
+
 // vim: et sw=4:
