@@ -1,7 +1,7 @@
 /*
  *  main.cpp
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -26,11 +26,6 @@
 
 int main(int argc, char* argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
-
     // Use QScopedPointer to ensure the QCoreApplication instance is deleted
     // before libraries unload, to avoid crashes during clean-up.
     QScopedPointer<KAlarmApp> app(KAlarmApp::create(argc, argv));
@@ -38,12 +33,12 @@ int main(int argc, char* argv[])
     const QStringList args = app->arguments();
     KCrash::initialize();
 
-    KLocalizedString::setApplicationDomain("kalarm");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kalarm"));
     KAboutData aboutData(QStringLiteral(PROGRAM_NAME), i18n(KALARM_NAME),
                          QStringLiteral(KALARM_VERSION " (KDE Gear " RELEASE_SERVICE_VERSION ")"),
                          i18n("Personal alarm message, command and email scheduler by KDE"),
                          KAboutLicense::GPL,
-                         ki18n("Copyright © 2001-%1, David Jarvie").subs(QStringLiteral("2024")).toString(), QString());
+                         ki18n("Copyright © 2001-%1, David Jarvie").subs(QStringLiteral("2023")).toString(), QString());
     aboutData.addAuthor(i18n("David Jarvie"), i18n("Author"), QStringLiteral("djarvie@kde.org"));
     aboutData.setOrganizationDomain("kde.org");
     aboutData.setDesktopFileName(QStringLiteral(KALARM_DBUS_SERVICE));
