@@ -1,7 +1,7 @@
 /*
  *  mainwindow.cpp  -  main application window
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -15,6 +15,7 @@
 #include "deferdlg.h"
 #include "functions.h"
 #include "kalarmapp.h"
+#include "kernelwakealarm.h"
 #include "newalarmaction.h"
 #include "prefdlg.h"
 #include "preferences.h"
@@ -52,7 +53,6 @@ using namespace KCalUtils;
 #include <KToggleAction>
 #include <KNotifyConfigWidget>
 #include <KToolBarPopupAction>
-#include <KWindowSystem>
 
 #include <QAction>
 #include <QSplitter>
@@ -127,7 +127,7 @@ MainWindow::MainWindow(bool restored)
     setWindowModality(Qt::WindowModal);
     setObjectName(QStringLiteral("MainWin"));    // used by LikeBack
     setPlainCaption(KAboutData::applicationData().displayName());
-    KConfigGroup config(KSharedConfig::openConfig(), VIEW_GROUP);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(VIEW_GROUP));
     mShowResources     = config.readEntry(SHOW_RESOURCES_KEY, false);
     mShowDateNavigator = config.readEntry(SHOW_DATE_NAVIGATOR, false);
     mDateNavigatorTop  = config.readEntry(DATE_NAVIGATOR_TOP, true);
@@ -366,7 +366,7 @@ void MainWindow::resizeEvent(QResizeEvent* re)
 /******************************************************************************
 * Emitted when the date selection changes in the date picker.
 */
-void MainWindow::datesSelected(const QVector<QDate>& dates, bool workChange)
+void MainWindow::datesSelected(const QList<QDate>& dates, bool workChange)
 {
     mListFilterModel->setDateFilter(dates, workChange);
 }
@@ -389,7 +389,7 @@ void MainWindow::resourcesResized()
             mResourcesWidth = 0;
         else if (mainMainWindow() == this)
         {
-            KConfigGroup config(KSharedConfig::openConfig(), VIEW_GROUP);
+            KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(VIEW_GROUP));
             config.writeEntry(SHOW_RESOURCES_KEY, mShowResources);
             if (mShowResources)
                 config.writeEntry(RESOURCES_WIDTH_KEY, mResourcesWidth);
@@ -456,31 +456,31 @@ void MainWindow::initActions()
 {
     KActionCollection* actions = actionCollection();
 
-    mActionTemplates = new QAction(i18nc("@action", "&Templates..."), this);
+    mActionTemplates = new QAction(i18nc("@action", "Templates..."), this);
     actions->addAction(QStringLiteral("templates"), mActionTemplates);
     connect(mActionTemplates, &QAction::triggered, this, &MainWindow::slotTemplates);
 
-    mActionNew = new NewAlarmAction(false, i18nc("@action", "&New"), this, actions);
+    mActionNew = new NewAlarmAction(false, i18nc("@action", "New"), this, actions);
     mActionNew->setActionNames(QStringLiteral("newDisplay"), QStringLiteral("newCommand"), QStringLiteral("newEmail"), QStringLiteral("newAudio"), QStringLiteral("newFromTemplate"));
     actions->addAction(QStringLiteral("new"), mActionNew);
     connect(mActionNew, &NewAlarmAction::selected, this, &MainWindow::slotNew);
     connect(mActionNew, &NewAlarmAction::selectedTemplate, this, &MainWindow::slotNewFromTemplate);
 
-    mActionCreateTemplate = new QAction(i18nc("@action", "Create Tem&plate..."), this);
+    mActionCreateTemplate = new QAction(i18nc("@action", "Create Template..."), this);
     actions->addAction(QStringLiteral("createTemplate"), mActionCreateTemplate);
     connect(mActionCreateTemplate, &QAction::triggered, this, &MainWindow::slotNewTemplate);
 
-    mActionCopy = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18nc("@action", "&Copy..."), this);
+    mActionCopy = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18nc("@action", "Copy..."), this);
     actions->addAction(QStringLiteral("copy"), mActionCopy);
     actions->setDefaultShortcut(mActionCopy, QKeySequence(Qt::SHIFT | Qt::Key_Insert));
     connect(mActionCopy, &QAction::triggered, this, &MainWindow::slotCopy);
 
-    mActionModify = new QAction(QIcon::fromTheme(QStringLiteral("document-properties")), i18nc("@action", "&Edit..."), this);
+    mActionModify = new QAction(QIcon::fromTheme(QStringLiteral("document-properties")), i18nc("@action", "Edit..."), this);
     actions->addAction(QStringLiteral("modify"), mActionModify);
     actions->setDefaultShortcut(mActionModify, QKeySequence(Qt::CTRL | Qt::Key_E));
     connect(mActionModify, &QAction::triggered, this, &MainWindow::slotModify);
 
-    mActionDelete = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18nc("@action", "&Delete"), this);
+    mActionDelete = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18nc("@action", "Delete"), this);
     actions->addAction(QStringLiteral("delete"), mActionDelete);
     actions->setDefaultShortcut(mActionDelete, QKeySequence::Delete);
     connect(mActionDelete, &QAction::triggered, this, &MainWindow::slotDeleteIf);
@@ -491,7 +491,7 @@ void MainWindow::initActions()
     actions->setDefaultShortcut(mActionDeleteForce, QKeySequence::Delete | Qt::SHIFT);
     connect(mActionDeleteForce, &QAction::triggered, this, &MainWindow::slotDeleteForce);
 
-    mActionReactivate = new QAction(i18nc("@action", "Reac&tivate"), this);
+    mActionReactivate = new QAction(i18nc("@action", "Reactivate"), this);
     actions->addAction(QStringLiteral("undelete"), mActionReactivate);
     actions->setDefaultShortcut(mActionReactivate, QKeySequence(Qt::CTRL | Qt::Key_R));
     connect(mActionReactivate, &QAction::triggered, this, &MainWindow::slotReactivate);
@@ -501,26 +501,30 @@ void MainWindow::initActions()
     actions->setDefaultShortcut(mActionEnable, QKeySequence(Qt::CTRL | Qt::Key_B));
     connect(mActionEnable, &QAction::triggered, this, &MainWindow::slotEnable);
 
-#if ENABLE_WAKE_FROM_SUSPEND
-    QAction* waction = new QAction(i18nc("@action", "Wake From Suspend..."), this);
-    actions->addAction(QStringLiteral("wakeSuspend"), waction);
-    connect(waction, &QAction::triggered, this, &MainWindow::slotWakeFromSuspend);
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
+    if (!KernelWakeAlarm::isAvailable())
+    {
+        // Only enable RTC wake from suspend if kernel wake alarms are not available
+        QAction* waction = new QAction(i18nc("@action", "Wake From Suspend..."), this);
+        actions->addAction(QStringLiteral("wakeSuspend"), waction);
+        connect(waction, &QAction::triggered, this, &MainWindow::slotWakeFromSuspend);
+    }
 #endif
 
     QAction* action = KAlarm::createStopPlayAction(this);
     actions->addAction(QStringLiteral("stopAudio"), action);
     KGlobalAccel::setGlobalShortcut(action, QList<QKeySequence>());  // allow user to set a global shortcut
 
-    mActionShowArchived = new KToggleAction(i18nc("@action", "Show Archi&ved Alarms"), this);
+    mActionShowArchived = new KToggleAction(i18nc("@action", "Show Archived Alarms"), this);
     actions->addAction(QStringLiteral("showArchivedAlarms"), mActionShowArchived);
     actions->setDefaultShortcut(mActionShowArchived, QKeySequence(Qt::CTRL | Qt::Key_P));
     connect(mActionShowArchived, &KToggleAction::triggered, this, &MainWindow::slotShowArchived);
 
-    mActionToggleTrayIcon = new KToggleAction(i18nc("@action", "Show in System &Tray"), this);
+    mActionToggleTrayIcon = new KToggleAction(i18nc("@action", "Show in System Tray"), this);
     actions->addAction(QStringLiteral("showInSystemTray"), mActionToggleTrayIcon);
     connect(mActionToggleTrayIcon, &KToggleAction::triggered, this, &MainWindow::slotToggleTrayIcon);
 
-    mActionToggleResourceSel = new KToggleAction(QIcon::fromTheme(QStringLiteral("view-choose")), i18nc("@action", "Show &Calendars"), this);
+    mActionToggleResourceSel = new KToggleAction(QIcon::fromTheme(QStringLiteral("view-choose")), i18nc("@action", "Show Calendars"), this);
     actions->addAction(QStringLiteral("showResources"), mActionToggleResourceSel);
     connect(mActionToggleResourceSel, &KToggleAction::triggered, this, &MainWindow::slotToggleResourceSelector);
 
@@ -528,14 +532,11 @@ void MainWindow::initActions()
     actions->addAction(QStringLiteral("showDateSelector"), mActionToggleDateNavigator);
     connect(mActionToggleDateNavigator, &KToggleAction::triggered, this, &MainWindow::slotToggleDateNavigator);
 
-    if (!KWindowSystem::isPlatformWayland())  // Wayland doesn't allow positioning of windows
-    {
-        mActionSpreadWindows = KAlarm::createSpreadWindowsAction(this);
-        actions->addAction(QStringLiteral("spread"), mActionSpreadWindows);
-        KGlobalAccel::setGlobalShortcut(mActionSpreadWindows, QList<QKeySequence>());  // allow user to set a global shortcut
-    }
+    mActionSpreadWindows = KAlarm::createSpreadWindowsAction(this);
+    actions->addAction(QStringLiteral("spread"), mActionSpreadWindows);
+    KGlobalAccel::setGlobalShortcut(mActionSpreadWindows, QList<QKeySequence>());  // allow user to set a global shortcut
 
-    mActionImportAlarms = new QAction(i18nc("@action", "Import &Alarms..."), this);
+    mActionImportAlarms = new QAction(i18nc("@action", "Import Alarms..."), this);
     actions->addAction(QStringLiteral("importAlarms"), mActionImportAlarms);
     connect(mActionImportAlarms, &QAction::triggered, this, &MainWindow::slotImportAlarms);
 
@@ -546,15 +547,15 @@ void MainWindow::initActions()
         connect(mActionImportBirthdays, &QAction::triggered, this, &MainWindow::slotBirthdays);
     }
 
-    mActionExportAlarms = new QAction(i18nc("@action", "E&xport Selected Alarms..."), this);
+    mActionExportAlarms = new QAction(i18nc("@action", "Export Selected Alarms..."), this);
     actions->addAction(QStringLiteral("exportAlarms"), mActionExportAlarms);
     connect(mActionExportAlarms, &QAction::triggered, this, &MainWindow::slotExportAlarms);
 
-    mActionExport = new QAction(i18nc("@action", "E&xport..."), this);
+    mActionExport = new QAction(i18nc("@action", "Export..."), this);
     actions->addAction(QStringLiteral("export"), mActionExport);
     connect(mActionExport, &QAction::triggered, this, &MainWindow::slotExportAlarms);
 
-    action = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18nc("@action", "&Refresh Alarms"), this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18nc("@action", "Refresh Alarms"), this);
     actions->addAction(QStringLiteral("refreshAlarms"), action);
     connect(action, &QAction::triggered, this, &MainWindow::slotRefreshAlarms);
 
@@ -610,15 +611,15 @@ void MainWindow::initActions()
     setStandardToolBarMenuEnabled(true);
     createGUI(UI_FILE);
     // Load menu and toolbar settings
-    applyMainWindowSettings(KSharedConfig::openConfig()->group(WINDOW_NAME));
+    applyMainWindowSettings(KSharedConfig::openConfig()->group(QLatin1String(WINDOW_NAME)));
 
     mContextMenu = static_cast<QMenu*>(factory()->container(QStringLiteral("listContext"), this));
     QMenu* actionsMenu = static_cast<QMenu*>(factory()->container(QStringLiteral("actions"), this));
     mMenuError = (!mContextMenu  ||  !actionsMenu  ||  !resourceContextMenu());
-    connect(mActionUndo->menu(), &QMenu::aboutToShow, this, &MainWindow::slotInitUndoMenu);
-    connect(mActionUndo->menu(), &QMenu::triggered, this, &MainWindow::slotUndoItem);
-    connect(mActionRedo->menu(), &QMenu::aboutToShow, this, &MainWindow::slotInitRedoMenu);
-    connect(mActionRedo->menu(), &QMenu::triggered, this, &MainWindow::slotRedoItem);
+    connect(mActionUndo->popupMenu(), &QMenu::aboutToShow, this, &MainWindow::slotInitUndoMenu);
+    connect(mActionUndo->popupMenu(), &QMenu::triggered, this, &MainWindow::slotUndoItem);
+    connect(mActionRedo->popupMenu(), &QMenu::aboutToShow, this, &MainWindow::slotInitRedoMenu);
+    connect(mActionRedo->popupMenu(), &QMenu::triggered, this, &MainWindow::slotRedoItem);
     connect(Undo::instance(), &Undo::changed, this, &MainWindow::slotUndoStatus);
     connect(mListView, &AlarmListView::findActive, this, &MainWindow::slotFindActive);
     Preferences::connect(&Preferences::archivedKeepDaysChanged, this, &MainWindow::updateKeepArchived);
@@ -670,7 +671,7 @@ void MainWindow::slotInitHamburgerMenu()
     menu->addAction(actions->action(QStringLiteral("showArchivedAlarms")));
     menu->addAction(actions->action(QStringLiteral("showDateSelector")));
     menu->addSeparator();
-    menu->addAction(actions->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
+    menu->addAction(actions->action(KStandardAction::name(KStandardAction::Quit)));
     mHamburgerMenu->setMenu(menu);
 }
 
@@ -802,14 +803,14 @@ void MainWindow::slotModify()
 */
 void MainWindow::slotDelete(bool force)
 {
-    QVector<KAEvent> events = mListView->selectedEvents();
+    QList<KAEvent> events = mListView->selectedEvents();
     if (!force  &&  Preferences::confirmAlarmDeletion())
     {
         int n = events.count();
         if (KAMessageBox::warningContinueCancel(this, i18ncp("@info", "Do you really want to delete the selected alarm?",
                                                              "Do you really want to delete the %1 selected alarms?", n),
                                                 i18ncp("@title:window", "Delete Alarm", "Delete Alarms", n),
-                                                KGuiItem(i18nc("@action:button", "&Delete"), QStringLiteral("edit-delete")),
+                                                KGuiItem(i18nc("@action:button", "Delete"), QStringLiteral("edit-delete")),
                                                 KStandardGuiItem::cancel(),
                                                 Preferences::CONFIRM_ALARM_DELETION)
             != KMessageBox::Continue)
@@ -850,12 +851,12 @@ void MainWindow::slotDelete(bool force)
 */
 void MainWindow::slotReactivate()
 {
-    QVector<KAEvent> events = mListView->selectedEvents();
+    QList<KAEvent> events = mListView->selectedEvents();
     mListView->clearSelection();
 
     // Add the alarms to the displayed lists and to the calendar file
     Resource resource;   // active alarms resource which alarms are restored to
-    QVector<int> ineligibleIndexes;
+    QList<int> ineligibleIndexes;
     const KAlarm::UpdateResult status = KAlarm::reactivateEvents(events, ineligibleIndexes, resource, this);
     if (status.status < KAlarm::UPDATE_FAILED)
     {
@@ -877,8 +878,8 @@ void MainWindow::slotReactivate()
 void MainWindow::slotEnable()
 {
     bool enable = mActionEnableEnable;    // save since changed in response to KAlarm::enableEvent()
-    const QVector<KAEvent> events = mListView->selectedEvents();
-    QVector<KAEvent> eventCopies;
+    const QList<KAEvent> events = mListView->selectedEvents();
+    QList<KAEvent> eventCopies;
     eventCopies.reserve(events.count());
     for (const KAEvent& event : events)
         eventCopies += event;
@@ -891,7 +892,7 @@ void MainWindow::slotEnable()
 */
 void MainWindow::slotAlarmListColumnsChanged()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), VIEW_GROUP);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(VIEW_GROUP));
     config.writeEntry(SHOW_COLUMNS, mListView->columnsVisible());
     config.sync();
 }
@@ -907,7 +908,7 @@ void MainWindow::slotShowArchived()
                                                   : i18nc("@info:tooltip", "Show Archived Alarms"));
     mListFilterModel->setEventTypeFilter(mShowArchived ? CalEvent::ACTIVE | CalEvent::ARCHIVED : CalEvent::ACTIVE);
     mListView->reset();
-    KConfigGroup config(KSharedConfig::openConfig(), VIEW_GROUP);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(VIEW_GROUP));
     config.writeEntry(SHOW_ARCHIVED_KEY, mShowArchived);
     config.sync();
 }
@@ -926,7 +927,7 @@ void MainWindow::slotSpreadWindowsShortcut()
 */
 void MainWindow::slotWakeFromSuspend()
 {
-#if ENABLE_WAKE_FROM_SUSPEND
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
     (WakeFromSuspendDlg::create(this))->show();
 #endif
 }
@@ -947,7 +948,7 @@ void MainWindow::slotImportAlarms()
 */
 void MainWindow::slotExportAlarms()
 {
-    const QVector<KAEvent> events = mListView->selectedEvents();
+    const QList<KAEvent> events = mListView->selectedEvents();
     if (!events.isEmpty())
         KAlarm::exportAlarms(events, this);
 }
@@ -966,7 +967,7 @@ void MainWindow::slotBirthdays()
         AutoQPointer<BirthdayDlg> dlg = new BirthdayDlg(this);
         if (dlg->exec() == QDialog::Accepted)
         {
-            QVector<KAEvent> events = dlg->events();
+            QList<KAEvent> events = dlg->events();
             if (!events.isEmpty())
             {
                 mListView->clearSelection();
@@ -1042,7 +1043,7 @@ void MainWindow::slotToggleResourceSelector()
         mResourceSelector->hide();
     arrangePanel();
 
-    KConfigGroup config(KSharedConfig::openConfig(), VIEW_GROUP);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(VIEW_GROUP));
     config.writeEntry(SHOW_RESOURCES_KEY, mShowResources);
     if (mShowResources)
         config.writeEntry(RESOURCES_WIDTH_KEY, mResourcesWidth);
@@ -1070,7 +1071,7 @@ void MainWindow::slotToggleDateNavigator()
     }
     arrangePanel();
 
-    KConfigGroup config(KSharedConfig::openConfig(), VIEW_GROUP);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(VIEW_GROUP));
     config.writeEntry(SHOW_DATE_NAVIGATOR, mShowDateNavigator);
     config.writeEntry(DATE_NAVIGATOR_TOP, mDateNavigatorTop);
     config.sync();
@@ -1206,7 +1207,7 @@ void MainWindow::slotRedoItem(QAction* action)
 */
 void MainWindow::slotInitUndoMenu()
 {
-    initUndoMenu(mActionUndo->menu(), Undo::UNDO);
+    initUndoMenu(mActionUndo->popupMenu(), Undo::UNDO);
 }
 
 /******************************************************************************
@@ -1215,7 +1216,7 @@ void MainWindow::slotInitUndoMenu()
 */
 void MainWindow::slotInitRedoMenu()
 {
-    initUndoMenu(mActionRedo->menu(), Undo::REDO);
+    initUndoMenu(mActionRedo->popupMenu(), Undo::REDO);
 }
 
 /******************************************************************************
@@ -1226,7 +1227,7 @@ void MainWindow::initUndoMenu(QMenu* menu, Undo::Type type)
     menu->clear();
     mUndoMenuIds.clear();
     const QString& action = (type == Undo::UNDO) ? undoTextStripped : redoTextStripped;
-    const QVector<int> ids = Undo::ids(type);
+    const QList<int> ids = Undo::ids(type);
     for (const int id : ids)
     {
         const QString actText = Undo::actionText(type, id);
@@ -1331,7 +1332,7 @@ void MainWindow::slotConfigureNotifications()
 */
 void MainWindow::slotConfigureToolbar()
 {
-    KConfigGroup grp(KSharedConfig::openConfig()->group(WINDOW_NAME));
+    KConfigGroup grp(KSharedConfig::openConfig()->group(QLatin1String(WINDOW_NAME)));
     saveMainWindowSettings(grp);
     KEditToolBar dlg(factory());
     connect(&dlg, &KEditToolBar::newToolBarConfig, this, &MainWindow::slotNewToolbarConfig);
@@ -1345,7 +1346,7 @@ void MainWindow::slotConfigureToolbar()
 void MainWindow::slotNewToolbarConfig()
 {
     createGUI(UI_FILE);
-    applyMainWindowSettings(KSharedConfig::openConfig()->group(WINDOW_NAME));
+    applyMainWindowSettings(KSharedConfig::openConfig()->group(QLatin1String(WINDOW_NAME)));
 }
 
 /******************************************************************************
@@ -1410,7 +1411,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 {
     qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: Formats:" << e->mimeData()->formats();
     const QMimeData* data = e->mimeData();
-    KAEvent::SubAction action = KAEvent::MESSAGE;
+    KAEvent::SubAction action = KAEvent::SubAction::Message;
     AlarmText          alarmText;
     MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::timeSpecAsZone()));
 #ifndef NDEBUG
@@ -1470,7 +1471,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
             if (start.isDateOnly())
                 flags |= KAEvent::ANY_TIME;
             KAEvent ev(start, todo->summary(), alarmText.displayText(), Preferences::defaultBgColour(), Preferences::defaultFgColour(),
-                       QFont(), KAEvent::MESSAGE, 0, flags, true);
+                       QFont(), KAEvent::SubAction::Message, 0, flags, true);
             ev.startChanges();
             if (todo->recurs())
             {
@@ -1517,7 +1518,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
             // Try to find the mime type of the file, without downloading a remote file
             QMimeDatabase mimeDb;
             const QString mimeTypeName = mimeDb.mimeTypeForUrl(url).name();
-            action = mimeTypeName.startsWith(QLatin1String("audio/")) ? KAEvent::AUDIO : KAEvent::FILE;
+            action = mimeTypeName.startsWith(QLatin1String("audio/")) ? KAEvent::SubAction::Audio : KAEvent::SubAction::File;
             alarmText.setText(url.toDisplayString());
         }
     }
@@ -1535,7 +1536,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 
     if (!alarmText.isEmpty())
     {
-        if (action == KAEvent::MESSAGE
+        if (action == KAEvent::SubAction::Message
         &&  (alarmText.isEmail() || alarmText.isScript()))
         {
             // If the alarm text could be interpreted as an email or command script,
@@ -1553,7 +1554,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
                 return;   // user didn't press OK
             int i = types.indexOf(type);
             if (i == 1)
-                action = alarmText.isEmail() ? KAEvent::EMAIL : KAEvent::COMMAND;
+                action = alarmText.isEmail() ? KAEvent::SubAction::Email : KAEvent::SubAction::Command;
         }
         KAlarm::editNewAlarm(action, win, &alarmText);
     }
@@ -1586,7 +1587,7 @@ void MainWindow::slotCalendarStatusChanged()
 void MainWindow::slotSelection()
 {
     // Find which events have been selected
-    QVector<KAEvent> events = mListView->selectedEvents();
+    QList<KAEvent> events = mListView->selectedEvents();
     int count = events.count();
     if (!count)
     {
@@ -1681,7 +1682,7 @@ void MainWindow::selectionCleared()
 void MainWindow::setEnableText(bool enable)
 {
     mActionEnableEnable = enable;
-    mActionEnable->setText(enable ? i18nc("@action", "Ena&ble") : i18nc("@action", "Disa&ble"));
+    mActionEnable->setText(enable ? i18nc("@action", "Enable") : i18nc("@action", "Disable"));
 }
 
 /******************************************************************************
@@ -1804,4 +1805,6 @@ void MainWindow::processDeferAlarmDlg(QObject* obj, int result)
     MessageDisplay::processDeferDlg(data, result);
 }
 
+#include "moc_mainwindow.cpp"
+
 // vim: et sw=4:
