@@ -1,7 +1,7 @@
 /*
  *  messagewindow.cpp  -  displays an alarm message in a window
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -36,12 +36,8 @@
 #include <KX11Extras>
 #include <KWindowInfo>
 #include <netwm.h>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <QGuiApplication>
 #endif
-#endif
 #include <QTextBrowser>
 #include <QScrollBar>
 #include <QCheckBox>
@@ -66,7 +62,7 @@ namespace
 
 enum FullScreenType { NoFullScreen = 0, FullScreen = 1, FullScreenActive = 2 };
 FullScreenType haveFullScreenWindow(int screen);
-FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, QVector<FullScreenType>& screenTypes);
+FullScreenType findFullScreenWindows(const QList<QRect>& screenRects, QList<FullScreenType>& screenTypes);
 
 const QLatin1String KMAIL_DBUS_SERVICE("org.kde.kmail");
 const QLatin1String KMAIL_DBUS_PATH("/KMail");
@@ -111,8 +107,7 @@ public:
     }
 };
 
-
-QVector<MessageWindow*> MessageWindow::mWindowList;
+QList<MessageWindow*> MessageWindow::mWindowList;
 
 /******************************************************************************
 * Construct the message window for the specified alarm.
@@ -206,7 +201,7 @@ void MessageWindow::setUpDisplay()
     mHelper->initTexts();
     MessageDisplayHelper::DisplayTexts texts = mHelper->texts();
 
-    const bool reminder = (!mErrorWindow()  &&  (mAlarmType() & KAAlarm::REMINDER_ALARM));
+    const bool reminder = (!mErrorWindow()  &&  (mAlarmType() & KAAlarm::Type::Reminder));
     const int leading = fontMetrics().leading();
     setCaption(texts.title);
     QWidget* topWidget = new QWidget(this);
@@ -238,7 +233,7 @@ void MessageWindow::setUpDisplay()
         // It's a normal alarm message window
         switch (mAction())
         {
-            case KAEvent::FILE:
+            case KAEvent::SubAction::File:
             {
                 // Display the file name
                 auto label = new KSqueezedTextLabel(texts.fileName, topWidget);
@@ -263,8 +258,8 @@ void MessageWindow::setUpDisplay()
 
                     switch (texts.fileType)
                     {
-                        case File::Image:
-                        case File::TextFormatted:
+                        case File::Type::Image:
+                        case File::Type::TextFormatted:
                             view->setHtml(texts.message);
                             break;
                         default:
@@ -284,7 +279,7 @@ void MessageWindow::setUpDisplay()
                 }
                 break;
             }
-            case KAEvent::MESSAGE:
+            case KAEvent::SubAction::Message:
             {
                 // Message label
                 // Using MessageText instead of QLabel allows scrolling and mouse copying
@@ -320,7 +315,7 @@ void MessageWindow::setUpDisplay()
                     topLayout->addStretch();
                 break;
             }
-            case KAEvent::COMMAND:
+            case KAEvent::SubAction::Command:
             {
                 mCommandText = new MessageText(topWidget);
                 mCommandText->setBackgroundColour(mBgColour());
@@ -331,7 +326,7 @@ void MessageWindow::setUpDisplay()
                 mCommandText->setPlainText(texts.message);
                 break;
             }
-            case KAEvent::EMAIL:
+            case KAEvent::SubAction::Email:
             default:
                 break;
         }
@@ -355,7 +350,7 @@ void MessageWindow::setUpDisplay()
         // It's an error message
         switch (mAction())
         {
-            case KAEvent::EMAIL:
+            case KAEvent::SubAction::Email:
             {
                 // Display the email addresses and subject.
                 QFrame* frame = new QFrame(topWidget);
@@ -375,9 +370,9 @@ void MessageWindow::setUpDisplay()
                 grid->addWidget(label, 1, 1, Qt::AlignLeft);
                 break;
             }
-            case KAEvent::COMMAND:
-            case KAEvent::FILE:
-            case KAEvent::MESSAGE:
+            case KAEvent::SubAction::Command:
+            case KAEvent::SubAction::File:
+            case KAEvent::SubAction::Message:
             default:
                 // Just display the error message strings
                 break;
@@ -432,7 +427,7 @@ void MessageWindow::setUpDisplay()
     if (mShowEdit())
     {
         // Edit button
-        mEditButton = new PushButton(i18nc("@action:button", "&Edit..."), topWidget);
+        mEditButton = new PushButton(i18nc("@action:button", "Edit..."), topWidget);
         mEditButton->setFocusPolicy(Qt::ClickFocus);    // don't allow keyboard selection
         connect(mEditButton, &QAbstractButton::clicked, this, &MessageWindow::slotEdit);
         grid->addWidget(mEditButton, 0, gridIndex++, Qt::AlignHCenter);
@@ -441,7 +436,7 @@ void MessageWindow::setUpDisplay()
     }
 
     // Defer button
-    mDeferButton = new PushButton(i18nc("@action:button", "&Defer..."), topWidget);
+    mDeferButton = new PushButton(i18nc("@action:button", "Defer..."), topWidget);
     mDeferButton->setFocusPolicy(Qt::ClickFocus);    // don't allow keyboard selection
     connect(mDeferButton, &QAbstractButton::clicked, this, &MessageWindow::slotDefer);
     grid->addWidget(mDeferButton, 0, gridIndex++, Qt::AlignHCenter);
@@ -512,15 +507,14 @@ void MessageWindow::setUpDisplay()
     topLayout->activate();
     setMinimumSize(QSize(grid->sizeHint().width() + dcmLeft + dcmRight,
                          sizeHint().height()));
+    const bool modal = !(windowFlags() & Qt::X11BypassWindowManagerHint);
 #if ENABLE_X11
-    if (KWindowSystem::isPlatformX11())
-    {
-        const bool modal = !(windowFlags() & Qt::X11BypassWindowManagerHint);
+    if (KWindowSystem::isPlatformX11()) {
         NET::States wstate = NET::Sticky | NET::KeepAbove;
         if (modal)
             wstate |= NET::Modal;
         WId winid = winId();
-        KWindowSystem::setState(winid, wstate);
+        KX11Extras::setState(winid, wstate);
         KX11Extras::setOnAllDesktops(winid, true);   // show on all virtual desktops
     }
 #endif
@@ -742,9 +736,6 @@ void MessageWindow::readProperties(const KConfigGroup& config)
 */
 bool MessageWindow::spread(bool scatter)
 {
-    if (KWindowSystem::isPlatformWayland())
-        return false;    // Wayland doesn't allow positioning of windows
-
     if (windowCount(true) <= 1)    // ignore always-hidden windows
         return false;
 
@@ -839,10 +830,10 @@ QSize MessageWindow::sizeHint() const
     QSize desired;
     switch (mAction())
     {
-        case KAEvent::MESSAGE:
+        case KAEvent::SubAction::Message:
             desired = MainWindowBase::sizeHint();
             break;
-        case KAEvent::COMMAND:
+        case KAEvent::SubAction::Command:
             if (mShown)
             {
                 // For command output, expand the window to accommodate the text
@@ -856,7 +847,7 @@ QSize MessageWindow::sizeHint() const
                 break;
             }
             // fall through to default
-            Q_FALLTHROUGH();
+            [[fallthrough]];
         default:
             return MainWindowBase::sizeHint();
     }
@@ -877,7 +868,7 @@ void MessageWindow::showEvent(QShowEvent* se)
     MainWindowBase::showEvent(se);
     if (mShown  ||  !mInitialised)
         return;
-    if (mErrorWindow()  ||  mAlarmType() == KAAlarm::INVALID_ALARM)
+    if (mErrorWindow()  ||  mAlarmType() == KAAlarm::Type::Invalid)
     {
         // Don't bother repositioning error messages,
         // and invalid alarms should be deleted anyway.
@@ -892,7 +883,7 @@ void MessageWindow::showEvent(QShowEvent* se)
          */
         bool execComplete = true;
         QSize s = sizeHint();     // fit the window round the message
-        if (mAction() == KAEvent::FILE  &&  mErrorMsgs().isEmpty())
+        if (mAction() == KAEvent::SubAction::File  &&  mErrorMsgs().isEmpty())
             Config::readWindowSize("FileMessage", s);
         resize(s);
 
@@ -969,8 +960,7 @@ void MessageWindow::showEvent(QShowEvent* se)
 void MessageWindow::moveEvent(QMoveEvent* e)
 {
     MainWindowBase::moveEvent(e);
-    if (!KWindowSystem::isPlatformWayland())  // Wayland doesn't allow positioning of windows
-        theApp()->setSpreadWindowsState(isSpread(Desktop::workArea(mScreenNumber).topLeft()));
+    theApp()->setSpreadWindowsState(isSpread(Desktop::workArea(mScreenNumber).topLeft()));
     if (mPositioning)
     {
         // The window has just been initially positioned
@@ -986,14 +976,13 @@ void MessageWindow::moveEvent(QMoveEvent* e)
 */
 void MessageWindow::frameDrawn()
 {
-    if (!mErrorWindow()  &&  mAction() == KAEvent::MESSAGE)
+    if (!mErrorWindow()  &&  mAction() == KAEvent::SubAction::Message)
     {
         const QSize s = sizeHint();
         if (width() > s.width()  ||  height() > s.height())
             resize(s);
     }
-    if (!KWindowSystem::isPlatformWayland())  // Wayland doesn't allow positioning of windows
-        theApp()->setSpreadWindowsState(isSpread(Desktop::workArea(mScreenNumber).topLeft()));
+    theApp()->setSpreadWindowsState(isSpread(Desktop::workArea(mScreenNumber).topLeft()));
 }
 
 /******************************************************************************
@@ -1048,7 +1037,7 @@ void MessageWindow::resizeEvent(QResizeEvent* re)
     }
     else
     {
-        if (mShown  &&  mAction() == KAEvent::FILE  &&  mErrorMsgs().isEmpty())
+        if (mShown  &&  mAction() == KAEvent::SubAction::File  &&  mErrorMsgs().isEmpty())
             Config::writeWindowSize("FileMessage", re->size());
         MainWindowBase::resizeEvent(re);
     }
@@ -1269,8 +1258,8 @@ bool MessageWindow::getWorkAreaAndModal()
         {
             // The screens form a single virtual desktop.
             // Xinerama, for example, uses this scheme.
-            QVector<FullScreenType> screenTypes(numScreens);
-            QVector<QRect> screenRects(numScreens);
+            QList<FullScreenType> screenTypes(numScreens);
+            QList<QRect> screenRects(numScreens);
             for (int s = 0;  s < numScreens;  ++s)
                 screenRects[s] = screens[s]->geometry();
             const FullScreenType full = findFullScreenWindows(screenRects, screenTypes);
@@ -1358,15 +1347,11 @@ FullScreenType haveFullScreenWindow(int screen)
 #if ENABLE_X11
     if (KWindowSystem::isPlatformX11())
     {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
         using namespace QNativeInterface;
         auto* x11App = qGuiApp->nativeInterface<QX11Application>();
         if (!x11App)
             return type;
         xcb_connection_t* connection = x11App->connection();
-#else
-        xcb_connection_t* connection = QX11Info::connection();
-#endif
         const NETRootInfo rootInfo(connection, NET::ClientList | NET::ActiveWindow, NET::Properties2(), screen);
         const xcb_window_t rootWindow   = rootInfo.rootWindow();
         const xcb_window_t activeWindow = rootInfo.activeWindow();
@@ -1392,7 +1377,7 @@ FullScreenType haveFullScreenWindow(int screen)
 * In a multi-screen setup (single virtual desktop, e.g. Xinerama), find which
 * screens have full screen windows on them.
 */
-FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, QVector<FullScreenType>& screenTypes)
+FullScreenType findFullScreenWindows(const QList<QRect>& screenRects, QList<FullScreenType>& screenTypes)
 {
     FullScreenType result = NoFullScreen;
     screenTypes.fill(NoFullScreen);
@@ -1400,15 +1385,11 @@ FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, QVector<
 #if ENABLE_X11
     if (KWindowSystem::isPlatformX11())
     {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
         using namespace QNativeInterface;
         auto* x11App = qGuiApp->nativeInterface<QX11Application>();
         if (!x11App)
             return result;
         xcb_connection_t* connection = x11App->connection();
-#else
-        xcb_connection_t* connection = QX11Info::connection();
-#endif
         const NETRootInfo rootInfo(connection, NET::ClientList | NET::ActiveWindow, NET::Properties2());
         const xcb_window_t rootWindow   = rootInfo.rootWindow();
         const xcb_window_t activeWindow = rootInfo.activeWindow();
@@ -1453,4 +1434,6 @@ FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, QVector<
 
 } // namespace
 
+#include "moc_messagewindow.cpp"
+
 // vim: et sw=4:
