@@ -1,7 +1,7 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -58,6 +58,7 @@ using namespace KHolidays;
 #include <QIcon>
 #if ENABLE_X11
 #include <KX11Extras>
+#include <KWindowInfo>
 #endif
 #include <KWindowSystem>
 #include <KHelpClient>
@@ -259,8 +260,8 @@ void KAlarmPrefDlg::slotDefault()
     switch (KAMessageBox::questionYesNoCancel(this,
                          i18nc("@info", "Reset all tabs to their default values, or only reset the current tab?"),
                          QString(),
-                         KGuiItem(i18nc("@action:button Reset ALL tabs", "&All")),
-                         KGuiItem(i18nc("@action:button Reset the CURRENT tab", "C&urrent"))))
+                         KGuiItem(i18nc("@action:button Reset ALL tabs", "All")),
+                         KGuiItem(i18nc("@action:button Reset the CURRENT tab", "Current"))))
     {
         case KMessageBox::ButtonCode::PrimaryAction:
             restore(true);   // restore all tabs
@@ -409,7 +410,7 @@ void PrefsTabBase::showEvent(QShowEvent*)
         int wid = 0;
         int i;
         const int labelCount = mLabels.count();
-        QVector<int> xpos;
+        QList<int> xpos;
         xpos.reserve(labelCount);
         for (const QLabel* label : std::as_const(mLabels))
         {
@@ -683,9 +684,13 @@ void MiscPrefTab::slotOtherTerminalToggled(bool on)
 TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     : PrefsTabBase(scrollGroup)
 {
+    const int marLeft  = style()->pixelMetric(QStyle::PM_LayoutLeftMargin);
+    const int marRight = style()->pixelMetric(QStyle::PM_LayoutRightMargin);
+    const int marTop   = style()->pixelMetric(QStyle::PM_LayoutTopMargin);
+
     // Default time zone
     auto itemBox = new QHBoxLayout();
-    itemBox->setContentsMargins(0, 0, 0, 0);
+    itemBox->setContentsMargins(marLeft, marTop, marRight, 0);
     topLayout()->addLayout(itemBox);
 
     QWidget* widget = new QWidget; // this is to control the QWhatsThis text display area
@@ -706,7 +711,7 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
 
     // Holiday region
     itemBox = new QHBoxLayout();
-    itemBox->setContentsMargins(0, 0, 0, 0);
+    itemBox->setContentsMargins(marLeft, 0, marRight, 0);
     topLayout()->addLayout(itemBox);
 
     widget = new QWidget;    // this is to control the QWhatsThis text display area
@@ -741,9 +746,34 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
         mHolidays->addItem(it.key(), it.value());
     }
 
+    if (KernelWakeAlarm::isAvailable())
+    {
+        // Wake from suspend in advance of alarm time
+        itemBox = new QHBoxLayout();
+        itemBox->setContentsMargins(marLeft, 0, marRight, 0);
+        topLayout()->addLayout(itemBox);
+
+        widget = new QWidget;   // this is to control the QWhatsThis text display area
+        itemBox->addWidget(widget);
+        box = new QHBoxLayout(widget);
+        box->setContentsMargins(0, 0, 0, 0);
+        label = new QLabel(i18nc("@label:spinbox How long before alarm to wake system from suspend", "Wake from suspend before alarm:"));
+        addAlignedLabel(label);
+        box->addWidget(label);
+        mPreWakeSuspend = new SpinBox;
+        mPreWakeSuspend->setMaximum(10);   // 10 minutes maximum
+        box->addWidget(mPreWakeSuspend);
+        label->setBuddy(mPreWakeSuspend);
+        widget->setWhatsThis(i18nc("@info:whatsthis",
+              "Enter how many minutes before the alarm trigger time to wake the system, for alarms set to wake from suspend. This can be used to ensure that the system is fully restored by the time the alarm triggers."));
+        label = new QLabel(i18nc("@label Time unit for user entered number", "minutes"));
+        box->addWidget(label);
+        itemBox->addStretch();
+    }
+
     // Start-of-day time
     itemBox = new QHBoxLayout();
-    itemBox->setContentsMargins(0, 0, 0, 0);
+    itemBox->setContentsMargins(marLeft, 0, marRight, 0);
     topLayout()->addLayout(itemBox);
 
     widget = new QWidget;   // this is to control the QWhatsThis text display area
@@ -846,6 +876,8 @@ void TimePrefTab::restore(bool, bool)
     mTimeZone->setTimeZone(timeSpec.type() == KADateTime::TimeZone ? timeSpec.timeZone() : QTimeZone());
     const int ix = Preferences::holidays().isValid() ? mHolidays->findData(Preferences::holidays().regionCode()) : 0;
     mHolidays->setCurrentIndex(ix);
+    if (mPreWakeSuspend)
+        mPreWakeSuspend->setValue(Preferences::wakeFromSuspendAdvance());
     mStartOfDay->setValue(Preferences::startOfDay());
     mWorkStart->setValue(Preferences::workDayStart());
     mWorkEnd->setValue(Preferences::workDayEnd());
@@ -864,6 +896,12 @@ bool TimePrefTab::apply(bool syncToDisc)
     const QString hol = mHolidays->itemData(mHolidays->currentIndex()).toString();
     if (hol != Preferences::holidays().regionCode())
         Preferences::setHolidayRegion(hol);
+    if (mPreWakeSuspend)
+    {
+        unsigned t = static_cast<unsigned>(mPreWakeSuspend->value());
+        if (t != Preferences::wakeFromSuspendAdvance())
+            Preferences::setWakeFromSuspendAdvance(t);
+    }
     int t = mStartOfDay->value();
     const QTime sodt(t/60, t%60, 0);
     if (sodt != Preferences::startOfDay())
@@ -928,7 +966,7 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     mPurgeArchived->setMinimumSize(mPurgeArchived->sizeHint());
     box->addWidget(mPurgeArchived);
     connect(mPurgeArchived, &QAbstractButton::toggled, this, &StorePrefTab::slotArchivedToggled);
-    mPurgeAfter = new SpinBox();
+    mPurgeAfter = new SpinBox;
     mPurgeAfter->setMinimum(1);
     mPurgeAfter->setSingleShiftStep(10);
     mPurgeAfter->setMinimumSize(mPurgeAfter->sizeHint());
@@ -1372,11 +1410,11 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget();
     widget->setFixedWidth(3 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     box->addWidget(widget);
-    QRadioButton* radio = new QRadioButton(i18nc("@option:radio", "February 2&8th"));
+    QRadioButton* radio = new QRadioButton(i18nc("@option:radio", "February 28th"));
     radio->setMinimumSize(radio->sizeHint());
     box->addWidget(radio);
     mFeb29->addButton(radio, Preferences::Feb29_Feb28);
-    radio = new QRadioButton(i18nc("@option:radio", "March &1st"));
+    radio = new QRadioButton(i18nc("@option:radio", "March 1st"));
     radio->setMinimumSize(radio->sizeHint());
     box->addWidget(radio);
     mFeb29->addButton(radio, Preferences::Feb29_Mar1);
@@ -1817,7 +1855,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     grid->setColumnMinimumWidth(0, gridIndentWidth());
     grid->setColumnMinimumWidth(1, gridIndentWidth());
 
-    mTooltipShowAlarms = new QCheckBox(i18nc("@option:check", "Show next &24 hours' alarms"), group);
+    mTooltipShowAlarms = new QCheckBox(i18nc("@option:check", "Show next 24 hours' alarms"), group);
     mTooltipShowAlarms->setMinimumSize(mTooltipShowAlarms->sizeHint());
     connect(mTooltipShowAlarms, &QAbstractButton::toggled, this, &ViewPrefTab::slotTooltipAlarmsToggled);
     mTooltipShowAlarms->setWhatsThis(
@@ -1906,26 +1944,22 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     topWindows->addWidget(group);
     grid = new QGridLayout(group);
     grid->setColumnStretch(1, 1);
-    if (!KWindowSystem::isPlatformWayland())  // Wayland doesn't allow positioning of windows
-    {
-        grid->setColumnMinimumWidth(0, gridIndentWidth());
+    grid->setColumnMinimumWidth(0, gridIndentWidth());
+    mWindowPosition = new ButtonGroup(group);
+    connect(mWindowPosition, &ButtonGroup::buttonSet, this, &ViewPrefTab::slotWindowPosChanged);
 
-        mWindowPosition = new ButtonGroup(group);
-        connect(mWindowPosition, &ButtonGroup::buttonSet, this, &ViewPrefTab::slotWindowPosChanged);
-
-        const QString whatsthis = xi18nc("@info:whatsthis",
-              "<para>Choose how to reduce the chance of alarm messages being accidentally acknowledged:"
-              "<list><item>Position alarm message windows as far as possible from the current mouse cursor location, or</item>"
-              "<item>Position alarm message windows in the center of the screen, but disable buttons for a short time after the window is displayed.</item></list></para>");
-        QRadioButton* radio = new QRadioButton(i18nc("@option:radio", "Position windows far from mouse cursor"), group);
-        mWindowPosition->addButton(radio, 0);
-        radio->setWhatsThis(whatsthis);
-        grid->addWidget(radio, 0, 0, 1, 2, Qt::AlignLeft);
-        radio = new QRadioButton(i18nc("@option:radio", "Center windows, delay activating window buttons"), group);
-        mWindowPosition->addButton(radio, 1);
-        radio->setWhatsThis(whatsthis);
-        grid->addWidget(radio, 1, 0, 1, 2, Qt::AlignLeft);
-    }
+    const QString whatsthis = xi18nc("@info:whatsthis",
+          "<para>Choose how to reduce the chance of alarm messages being accidentally acknowledged:"
+          "<list><item>Position alarm message windows as far as possible from the current mouse cursor location, or</item>"
+          "<item>Position alarm message windows in the center of the screen, but disable buttons for a short time after the window is displayed.</item></list></para>");
+    QRadioButton* radio = new QRadioButton(i18nc("@option:radio", "Position windows far from mouse cursor"), group);
+    mWindowPosition->addButton(radio, 0);
+    radio->setWhatsThis(whatsthis);
+    grid->addWidget(radio, 0, 0, 1, 2, Qt::AlignLeft);
+    radio = new QRadioButton(i18nc("@option:radio", "Center windows, delay activating window buttons"), group);
+    mWindowPosition->addButton(radio, 1);
+    radio->setWhatsThis(whatsthis);
+    grid->addWidget(radio, 1, 0, 1, 2, Qt::AlignLeft);
 
     widget = new QWidget;   // this is to control the QWhatsThis text display area
     box = new QHBoxLayout(widget);
@@ -2000,8 +2034,7 @@ void ViewPrefTab::restore(bool, bool allTabs)
     }
     if (allTabs  ||  mTabs->currentIndex() == mTabWindows)
     {
-        if (mWindowPosition)
-            mWindowPosition->setButton(Preferences::messageButtonDelay() ? 1 : 0);
+        mWindowPosition->setButton(Preferences::messageButtonDelay() ? 1 : 0);
         mWindowButtonDelay->setValue(Preferences::messageButtonDelay());
         if (mModalMessages)
             mModalMessages->setChecked(Preferences::modalMessages());
@@ -2046,7 +2079,7 @@ bool ViewPrefTab::apply(bool syncToDisc)
         if (n != Preferences::autoHideSystemTray())
             Preferences::setAutoHideSystemTray(n);
     }
-    n = mWindowPosition ? mWindowPosition->selectedId() : 1;
+    n = mWindowPosition->selectedId();
     if (n)
         n = mWindowButtonDelay->value();
     if (n != Preferences::messageButtonDelay())
@@ -2126,12 +2159,10 @@ void ViewPrefTab::slotAutoHideSysTrayChanged(QAbstractButton* button)
 
 void ViewPrefTab::slotWindowPosChanged(QAbstractButton* button)
 {
-    const bool enable = mWindowPosition ? mWindowPosition->id(button) : true;
+    const bool enable = mWindowPosition->id(button);
     mWindowButtonDelay->setEnabled(enable);
     mWindowButtonDelayLabel->setEnabled(enable);
 }
-
 #include "moc_prefdlg_p.cpp"
 #include "moc_prefdlg.cpp"
-
 // vim: et sw=4:
