@@ -1,7 +1,7 @@
 /*
  *  preferences.cpp  -  program preference settings
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -18,8 +18,8 @@
 #include "kalarmcalendar/identities.h"
 #include "kalarm_debug.h"
 
-#include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
+#include <KIdentityManagementCore/Identity>
+#include <KIdentityManagementCore/IdentityManager>
 
 #include <KSharedConfig>
 #include <KConfigGroup>
@@ -59,7 +59,7 @@ const QString FROM_KMAIL(QStringLiteral("@KMail"));
 // %w = command to execute in terminal, with 'sleep 86400' appended
 // %C = temporary command file to execute in terminal
 // %W = temporary command file to execute in terminal, with 'sleep 86400' appended
-const QVector<QString> xtermCommands {
+const QList<QString> xtermCommands {
     QStringLiteral("xterm -sb -hold -title %t -e %c"),
     QStringLiteral("konsole --noclose -p tabtitle=%t -e ${SHELL:-sh} -c %c"),
     QStringLiteral("gnome-terminal -t %t -e %W"),
@@ -69,7 +69,7 @@ const QVector<QString> xtermCommands {
     QStringLiteral("xfce4-terminal -T %t -H -e %c")
 };
 
-QVector<QString> xtermCommandExes;   // initialised to hold executables in xtermCommands
+QList<QString> xtermCommandExes;   // initialised to hold executables in xtermCommands
 
 void splitXTermCommands();
 
@@ -247,9 +247,6 @@ void Preferences::setNoAutoStart(bool yes)
             return;
         }
         QTextStream stream(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        stream.setCodec("UTF-8");
-#endif
         stream.setAutoDetectUnicode(true);
         lines = stream.readAll().split(QLatin1Char('\n'));
         for (int i = 0; i < lines.size(); ++i)
@@ -297,9 +294,6 @@ void Preferences::setNoAutoStart(bool yes)
             return;
         }
         QTextStream stream(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        stream.setCodec("UTF-8");
-#endif
         stream << lines.join(QLatin1Char('\n')) << "\n";
         // QSaveFile doesn't report a write error when the device is full (see Qt
         // bug 75077), so check that the data can actually be written by flush().
@@ -331,18 +325,6 @@ void Preferences::setModalMessages(bool yes)
         self()->setBase_ModalMessages(yes);
 }
 
-/******************************************************************************
-* Get the delay in seconds after a message window is displayed before its
-* buttons are activated.
-* Reply = 0 for no delay, but position windows as far from cursor as possible.
-*/
-int Preferences::messageButtonDelay()
-{
-    const int delay = self()->base_MessageButtonDelay();
-    // On Wayland, window positions can't be set, so return a minimum delay of 1 second.
-    return (delay <= 0  &&  KWindowSystem::isPlatformWayland()) ? 1 : delay;
-}
-
 /******************************************************************************
 * Get the user's time zone, or if none has been chosen, the system time zone.
 * Reply = time zone, or invalid to use the local time zone.
@@ -680,7 +662,7 @@ QString translateXTermPath(const QString& cmdline, bool write)
 
     // Translate any home directory specification at the start of the
     // executable's path.
-    KConfigGroup group(KSharedConfig::openConfig(), GENERAL_SECTION);
+    KConfigGroup group(KSharedConfig::openConfig(), QLatin1String(GENERAL_SECTION));
     if (write)
     {
         group.writePathEntry(TEMP, cmd);
@@ -695,4 +677,6 @@ QString translateXTermPath(const QString& cmdline, bool write)
     return cmd + params;
 }
 
+#include "moc_preferences.cpp"
+
 // vim: et sw=4:
